==> vradi-swing-0.3.2-sources.jar: com/jurismarches/vradi/ui/admin/helpers/AdminBeanConstant.java <==
/*
 * #%L
 * Vradi :: Swing
 * 
 * $Id: AdminBeanConstant.java 1614 2010-10-06 15:00:24Z sletellier $
 * $HeadURL: svn+ssh://sletellier@labs.libre-entreprise.org/svnroot/vradi/vradi/tags/vradi-0.3.2/vradi-swing/src/main/java/com/jurismarches/vradi/ui/admin/helpers/AdminBeanConstant.java $
 * %%
 * Copyright (C) 2009 - 2010 JurisMarches, Codelutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */
/* *##%
 * Copyright (C) 2010 Code Lutin, Chatellier Eric
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *##%*/

package com.jurismarches.vradi.ui.admin.helpers;

import static org.nuiton.i18n.I18n._;
import static org.nuiton.i18n.I18n.n_;

import java.util.Date;

import org.nuiton.wikitty.WikittyExtension;
import org.nuiton.wikitty.WikittyProxy;

import com.jurismarches.vradi.entities.Client;
import com.jurismarches.vradi.entities.ClientImpl;
import com.jurismarches.vradi.entities.Group;
import com.jurismarches.vradi.entities.GroupImpl;
import com.jurismarches.vradi.entities.Status;
import com.jurismarches.vradi.entities.User;
import com.jurismarches.vradi.entities.UserImpl;
import com.jurismarches.vradi.entities.WebHarvestStream;
import com.jurismarches.vradi.entities.WebHarvestStreamImpl;
import com.jurismarches.vradi.entities.XmlStream;
import com.jurismarches.vradi.entities.XmlStreamImpl;
import com.jurismarches.vradi.ui.admin.content.AdminClientUI;
import com.jurismarches.vradi.ui.admin.content.AdminFormTypeUI;
import com.jurismarches.vradi.ui.admin.content.AdminGroupUI;
import com.jurismarches.vradi.ui.admin.content.AdminStatusUI;
import com.jurismarches.vradi.ui.admin.content.AdminUserUI;
import com.jurismarches.vradi.ui.admin.content.AdminXmlStreamUI;
import com.jurismarches.vradi.ui.tree.VradiDataProvider;

/**
 * 
 * @author sletellier
 * @version $Revision: 1614 $
 * 
 * Last update : $Date: 2010-10-06 17:00:24 +0200 (mer., 06 oct. 2010) $
 * By : $Author: sletellier $
 */
public enum AdminBeanConstant {
    // Client category
    CLIENT(n_("vradi.client.category"), n_("vradi.adminClient.newClientName"), Client.class, AdminClientUI.class),
    // Group category
    GROUP(n_("vradi.group.category"), n_("vradi.adminGroup.newGroupName"), Group.class, AdminGroupUI.class),
    // User category
    USER(n_("vradi.user.category"), n_("vradi.adminUser.newUserName"), User.class, AdminUserUI.class),
    // Status category
    STATUS(n_("vradi.status.category"), n_("vradi.adminStatus.newStatusName"), Status.class, AdminStatusUI.class),
    // Stream category
    XML_STREAM(n_("vradi.stream.category"), n_("vradi.adminXmlStream.newStreamName"), XmlStream.class, AdminXmlStreamUI.class),
    // Stream category
    WEB_HARVEST_STREAM(n_("vradi.stream.category"), n_("vradi.adminXmlStream.newWebHarvestStreamName"), WebHarvestStream.class, AdminXmlStreamUI.class),
    // Form type category
    FORM_TYPE(n_("vradi.formType.category"), n_("vradi.adminXmlStream.newFormTypeName"), WikittyExtension.class, AdminFormTypeUI.class);

    private String categoryName;
    private String newEntityName;
    private Class<?> beanClass;
    private Class<?> uiClass;

    private AdminBeanConstant(String categoryName, String newEntityName, Class<?> beanClass, Class<?> uiClass) {
        this.categoryName = categoryName;
        this.newEntityName = newEntityName;
        this.beanClass = beanClass;
        this.uiClass = uiClass;
    }

    public String getCategoryName() {
        return categoryName;
    }

    public String getNewEntityName() {
        return _(newEntityName);
    }

    public Class<?> getBeanClass() {
        return beanClass;
    }

    public Class<?> getUIClass() {
        return uiClass;
    }

    public static AdminBeanConstant getConstantByUIClass(Class uiClass) {
        for (AdminBeanConstant constant : values()) {
            if (uiClass.equals(constant.getUIClass())){
                return constant;
            }
        }
        return null;
    }
    public static AdminBeanConstant getConstantByBeanClass(Class beanClass) {
        for (AdminBeanConstant constant : values()) {
            if (beanClass.equals(constant.getBeanClass())){
                return constant;
            }
        }
        return null;
    }

    public Object getBean(VradiDataProvider provider, String id) {
        WikittyProxy proxy = provider.getWikittyProxy();
        Object result = null;
        switch(this) {
            case CLIENT:
                if (id == null) {
                    Client newClient = new ClientImpl();
                    newClient.setName(getNewEntityName());
                    result = newClient;
                } else {
                    result = proxy.restore(Client.class, id);
                }
                break;
            case GROUP:
                if (id == null) {
                    Group newGroup = new GroupImpl();
                    newGroup.setName(getNewEntityName());
                    result = newGroup;
                } else {
                    result = proxy.restore(Group.class, id);
                }
                break;
            case USER:
                if (id == null) {
                    User newUser = new UserImpl();
                    newUser.setCreationDate(new Date());
                    newUser.setBeginSearchDate(new Date());
                    newUser.setName(getNewEntityName());
                    newUser.setEnable(true);
                    result = newUser;
                } else {
                    result = proxy.restore(User.class, id);
                }
                break;
            case FORM_TYPE:
                result = proxy.restoreExtensionLastVersion(id);
                break;
            case XML_STREAM:
                if (id == null) {
                    XmlStream newXmlStream = new XmlStreamImpl();
                    newXmlStream.setName(getNewEntityName());
                    result = newXmlStream;
                } else {
                    result = proxy.restore(XmlStream.class, id);
                }
                break;
            case WEB_HARVEST_STREAM:
                if (id == null) {
                    WebHarvestStream newWebHarvest = new WebHarvestStreamImpl();
                    newWebHarvest.setName(_(getNewEntityName()));
                    result = newWebHarvest;
                } else {
                    result = proxy.restore(WebHarvestStream.class, id);
                }
                break;
        }
        return result;
    }

    public static Class<?> getUIClass(String categoryName) {
        for (AdminBeanConstant constant : values()) {

            // For user category : clientId + CategoryUserName
            if (categoryName.matches(".*" + constant.getCategoryName())){
                return constant.getUIClass();
            }
        }
        return null;
    }

    public static Class<?> getUIClass(Class<?> beanClass) {
        for (AdminBeanConstant constant : values()) {
            if (beanClass.equals(constant.getBeanClass())){
                return constant.getUIClass();
            }
        }
        return null;
    }
}

==> vradi-swing-0.4.0-sources.jar: com/jurismarches/vradi/ui/admin/helpers/AdminBeanConstant.java <==
/*
 * #%L
 * Vradi :: Swing
 * 
 * $Id: AdminBeanConstant.java 1790 2010-11-16 15:28:43Z sletellier $
 * $HeadURL: svn+ssh://sletellier@labs.libre-entreprise.org/svnroot/vradi/vradi/tags/vradi-0.4.0/vradi-swing/src/main/java/com/jurismarches/vradi/ui/admin/helpers/AdminBeanConstant.java $
 * %%
 * Copyright (C) 2009 - 2010 JurisMarches, Codelutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */
/* *##%
 * Copyright (C) 2010 Code Lutin, Chatellier Eric
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *##%*/

package com.jurismarches.vradi.ui.admin.helpers;

import static org.nuiton.i18n.I18n._;
import static org.nuiton.i18n.I18n.n_;

import java.util.Date;

import org.nuiton.wikitty.WikittyExtension;
import org.nuiton.wikitty.WikittyProxy;

import com.jurismarches.vradi.entities.Client;
import com.jurismarches.vradi.entities.ClientImpl;
import com.jurismarches.vradi.entities.Group;
import com.jurismarches.vradi.entities.GroupImpl;
import com.jurismarches.vradi.entities.Status;
import com.jurismarches.vradi.entities.User;
import com.jurismarches.vradi.entities.UserImpl;
import com.jurismarches.vradi.entities.WebHarvestStream;
import com.jurismarches.vradi.entities.WebHarvestStreamImpl;
import com.jurismarches.vradi.entities.XmlStream;
import com.jurismarches.vradi.entities.XmlStreamImpl;
import com.jurismarches.vradi.ui.admin.content.AdminClientUI;
import com.jurismarches.vradi.ui.admin.content.AdminFormTypeUI;
import com.jurismarches.vradi.ui.admin.content.AdminGroupUI;
import com.jurismarches.vradi.ui.admin.content.AdminStatusUI;
import com.jurismarches.vradi.ui.admin.content.AdminUserUI;
import com.jurismarches.vradi.ui.admin.content.AdminXmlStreamUI;
import com.jurismarches.vradi.ui.tree.VradiDataProvider;

/**
 * 
 * @author sletellier
 * @version $Revision: 1790 $
 * 
 * Last update : $Date: 2010-11-16 16:28:43 +0100 (mar., 16 nov. 2010) $
 * By : $Author: sletellier $
 */
public enum AdminBeanConstant {
    // Client category
    CLIENT(n_("vradi.client.category"), n_("vradi.adminClient.newClientName"), Client.class, AdminClientUI.class),
    // Group category
    GROUP(n_("vradi.group.category"), n_("vradi.adminGroup.newGroupName"), Group.class, AdminGroupUI.class),
    // User category
    USER(n_("vradi.user.category"), n_("vradi.adminUser.newUserName"), User.class, AdminUserUI.class),
    // Status category
    STATUS(n_("vradi.status.category"), n_("vradi.adminStatus.newStatusName"), Status.class, AdminStatusUI.class),
    // Stream category
    XML_STREAM(n_("vradi.stream.category"), n_("vradi.adminXmlStream.newStreamName"), XmlStream.class, AdminXmlStreamUI.class),
    // Stream category
    WEB_HARVEST_STREAM(n_("vradi.stream.category"), n_("vradi.adminXmlStream.newWebHarvestStreamName"), WebHarvestStream.class, AdminXmlStreamUI.class),
    // Form type category
    FORM_TYPE(n_("vradi.formType.category"), n_("vradi.adminXmlStream.newFormTypeName"), WikittyExtension.class, AdminFormTypeUI.class);

    private String categoryName;
    private String newEntityName;
    private Class<?> beanClass;
    private Class<?> uiClass;

    private AdminBeanConstant(String categoryName, String newEntityName, Class<?> beanClass, Class<?> uiClass) {
        this.categoryName = categoryName;
        this.newEntityName = newEntityName;
        this.beanClass = beanClass;
        this.uiClass = uiClass;
    }

    public String getCategoryName() {
        return categoryName;
    }

    public String getNewEntityName() {
        return _(newEntityName);
    }

    public Class<?> getBeanClass() {
        return beanClass;
    }

    public Class<?> getUIClass() {
        return uiClass;
    }

    public static AdminBeanConstant getConstantByUIClass(Class uiClass) {
        for (AdminBeanConstant constant : values()) {
            if (uiClass.equals(constant.getUIClass())){
                return constant;
            }
        }
        return null;
    }
    public static AdminBeanConstant getConstantByBeanClass(Class beanClass) {
        for (AdminBeanConstant constant : values()) {
            if (beanClass.equals(constant.getBeanClass())){
                return constant;
            }
        }
        return null;
    }

    public Object getBean(WikittyProxy proxy, String id) {
        Object result = null;
        switch(this) {
            case CLIENT:
                if (id == null) {
                    Client newClient = new ClientImpl();
                    newClient.setName(getNewEntityName());
                    result = newClient;
                } else {
                    result = proxy.restore(Client.class, id);
                }
                break;
            case GROUP:
                if (id == null) {
                    Group newGroup = new GroupImpl();
                    newGroup.setName(getNewEntityName());
                    result = newGroup;
                } else {
                    result = proxy.restore(Group.class, id);
                }
                break;
            case USER:
                if (id == null) {
                    User newUser = new UserImpl();
                    newUser.setCreationDate(new Date());
                    newUser.setBeginSearchDate(new Date());
                    newUser.setName(getNewEntityName());
                    newUser.setEnable(true);
                    newUser.setValidEmail(false);
                    result = newUser;
                } else {
                    result = proxy.restore(User.class, id);
                }
                break;
            case FORM_TYPE:
                result = proxy.restoreExtensionLastVersion(id);
                break;
            case XML_STREAM:
                if (id == null) {
                    XmlStream newXmlStream = new XmlStreamImpl();
                    newXmlStream.setName(getNewEntityName());
                    result = newXmlStream;
                } else {
                    result = proxy.restore(XmlStream.class, id);
                }
                break;
            case WEB_HARVEST_STREAM:
                if (id == null) {
                    WebHarvestStream newWebHarvest = new WebHarvestStreamImpl();
                    newWebHarvest.setName(_(getNewEntityName()));
                    result = newWebHarvest;
                } else {
                    result = proxy.restore(WebHarvestStream.class, id);
                }
                break;
        }
        return result;
    }

    public static Class<?> getUIClass(String categoryName) {
        for (AdminBeanConstant constant : values()) {

            // For user category : clientId + CategoryUserName
            if (categoryName.matches(".*" + constant.getCategoryName())){
                return constant.getUIClass();
            }
        }
        return null;
    }

    public static Class<?> getUIClass(Class<?> beanClass) {
        for (AdminBeanConstant constant : values()) {
            if (beanClass.equals(constant.getBeanClass())){
                return constant.getUIClass();
            }
        }
        return null;
    }
}
